(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue-click-outside'), require('lb-vue-pagination')) :
    typeof define === 'function' && define.amd ? define(['exports', 'vue-click-outside', 'lb-vue-pagination'], factory) :
    (global = global || self, factory(global.LbVueSelect = {}, global.ClickOutside, global.Pagination));
}(this, (function (exports, ClickOutside, Pagination) { 'use strict';

    ClickOutside = ClickOutside && Object.prototype.hasOwnProperty.call(ClickOutside, 'default') ? ClickOutside['default'] : ClickOutside;
    Pagination = Pagination && Object.prototype.hasOwnProperty.call(Pagination, 'default') ? Pagination['default'] : Pagination;

    //

    var script = {
        name: 'LbSelect',
        props: {
            value: {
                type: [String, Number],
            },
            list: {
                type: Array,
            },
            pagination: {
                type: Object,
            },
            displayField: {
                type: String,
                default: 'key',
            },
            displayFunc: {
                type: Function,
            },
            valueField: {
                type: String,
                default: 'value',
            },
            multiselect: {
                type: Boolean,
                default: false,
            },
            searchBox: {
                type: Boolean,
                default: false,
            },
            empty: {
                type: Boolean,
                default: false,
            },
            searchPlaceholder: {
                type: String,
                default: undefined,
            },
            itemsPlaceholder: {
                type: String,
                default: undefined,
            },
            totalCount: {
                type: Number,
                default: undefined,
            },
            css: {
                type: String,
                default: 'form-control',
            },
            selectAll: {
                type: String,
                default: undefined,
            },
            allSelectedText: {
                type: String,
                default: undefined,
            },
            disabled: {
                type: Boolean,
                default: false,
            },
        },
        data: function data()
        {
            return {
                showSelector: false,
                selectedItems: [],
                checked: false,
                filterString: '',
            };
        },
        directives: {
            'click-outside': ClickOutside,
        },
        components:
        {
            pagination: Pagination,
        },
        created: function created()
        {
            var me = this;

            me.fillInitialValue();
        },
        methods:
        {
            selectAllClick: function selectAllClick()
            {
                var me = this;

                if (me.checked === true)
                {
                    me.checked = false;
                    me.$emit('change', '');
                    me.$emit('input', '');

                    for (var i = 0, list = me.list; i < list.length; i += 1)
                    {
                        var item = list[i];

                        item.isSelected = false;
                    }
                }
            },
            clickSelector: function clickSelector()
            {
                var me = this;

                me.$emit('click');

                if (me.disabled !== true)
                {
                    me.showSelector = !me.showSelector;
                }
                else
                {
                    me.showSelector = false;
                }
            },
            recursChildNodes: function recursChildNodes(childNodes, target)
            {
                for (var i = 0, list = childNodes; i < list.length; i += 1)
                {
                    var node = list[i];

                    if (node === target)
                    {
                        return true;
                    }

                    if (this.recursChildNodes(node.childNodes, target))
                    {
                        return true;
                    }
                }
                return false;
            },
            clickOutsideHandler: function clickOutsideHandler(evt)
            {
                if (this.showSelector)
                {
                    var ref = evt.composedPath();
                    var clickedElement = ref[0];

                    if (clickedElement
                    && this.recursChildNodes(this.$refs['lb-vue-sel-select'].childNodes, clickedElement))
                    {
                        return;
                    }

                    this.close();
                }
            },
            close: function close()
            {
                var me = this;
                me.showSelector = false;
            },
            reload: function reload()
            {
                var me = this;

                me.$emit('reload');
            },
            getDisplayText: function getDisplayText(item)
            {
                var me = this;

                if (me.displayFunc !== undefined)
                {
                    return me.displayFunc(item);
                }

                return item[me.displayField];
            },
            selectItem: function selectItem(item)
            {
                var me = this;

                var index = me.selectedItems.indexOf(item);
                if (me.multiselect)
                {
                    if (index === -1)
                    {
                        item.isSelected = true;
                        me.selectedItems.push(item);
                    }
                    else
                    {
                        item.isSelected = false;
                        me.selectedItems.splice(index, 1);

                        if (me.selectAll)
                        {
                            me.checked = false;
                        }
                    }
                }
                else if (me.empty)
                {
                    if (index !== -1)
                    {
                        me.selectedItems.splice(0);
                    }
                    else
                    {
                        me.list.forEach(function (element) {
                            element.isSelected = false;
                        });
                        me.selectedItems.splice(0);
                        me.selectedItems.push(item);
                    }
                }
                else
                {
                    me.list.forEach(function (element) {
                        element.isSelected = false;
                    });
                    me.selectedItems.splice(0);
                    me.selectedItems.push(item);
                }

                var valueArr = [];

                for (var i = 0, list = me.selectedItems; i < list.length; i += 1)
                {
                    var val = list[i];

                    valueArr.push(val[me.valueField]);
                }

                me.$emit('change', valueArr.join(','));

                me.$emit('input', valueArr.join(','));

                if (!me.multiselect)
                {
                    me.close();
                }
            },
            fillInitialValue: function fillInitialValue()
            {
                var me = this;

                me.selectedItems = [];

                if (!me.list)
                {
                    return;
                }

                if (me.list.length === undefined)
                {
                    console.error('lb-vue-select: List is not an array');
                }

                if (me.value === undefined || me.value == null)
                {
                    return;
                }

                var isNumber = false;
                var tempValue = me.value;

                if (typeof tempValue === 'number')
                {
                    tempValue = tempValue.toString();
                    isNumber = true;
                }

                var valueArr = tempValue.split(',');

                var valuesFromList = me.list.map(function (item) {
                    if (item[me.valueField] == null)
                    {
                        return null;
                    }
                    return item[me.valueField].toString();
                });
                if (me.multiselect && me.selectAll && valuesFromList.every(function (item) { return valueArr.includes(item); }))
                {
                    me.checked = true;
                }

                if (me.multiselect && me.selectAll && me.checked)
                {
                    for (var i = 0, list = me.list; i < list.length; i += 1)
                    {
                        var item = list[i];

                        me.selectItem(item);
                    }
                }

                for (var i$3 = 0, list$3 = valueArr; i$3 < list$3.length; i$3 += 1)
                {
                    var val = list$3[i$3];

                    if (val === '')
                    {
                        continue;
                    }
                    if (isNumber)
                    {
                        val = parseInt(val, 10);
                    }
                    var foundInList = false;
                    for (var i$2 = 0, list$2 = me.list; i$2 < list$2.length; i$2 += 1)
                    {
                        var item$1 = list$2[i$2];

                        if (!me.multiselect)
                        {
                            item$1.isSelected = false;
                        }

                        if (String(item$1[me.valueField]) === String(val))
                        {
                            foundInList = true;
                            var found = false;
                            for (var i$1 = 0, list$1 = me.selectedItems; i$1 < list$1.length; i$1 += 1)
                            {
                                var sel = list$1[i$1];

                                if (String(sel[me.valueField]) === String(val))
                                {
                                    found = true;
                                }
                            }
                            if (!found)
                            {
                                item$1.isSelected = true;
                                me.selectedItems.push(item$1);
                            }
                        }
                    }

                    if (!foundInList && me.pagination !== undefined)
                    {
                        if (me.multiselect)
                        {
                            if (!me.pagination.initialId.includes(val))
                            {
                                me.pagination.initialId.push(val);
                            }
                        }
                        else
                        {
                            me.pagination.initialId.splice(0);
                            me.pagination.initialId.push(val);
                        }
                    }
                }
            },
        },
        computed:
        {
            displayValue: function displayValue()
            {
                var me = this;

                me.setInitialId();

                return me.value;
            },
            filteredList: function filteredList()
            {
                var me = this;

                var items = [];

                if (me.filterString === '')
                {
                    return me.list;
                }

                for (var i = 0, list = me.list; i < list.length; i += 1)
                {
                    var item = list[i];

                    if (me.getDisplayText(item).toLowerCase().includes(me.filterString))
                    {
                        items.push(item);
                    }
                }

                return items;
            },
        },
        watch:
        {
            value: function value()
            {
                var me = this;

                me.fillInitialValue();
            },
            list:
            {
                handler: function handler(oldVal, val)
                {
                    var me = this;
                    if (JSON.stringify(oldVal) !== JSON.stringify(val))
                    {
                        me.fillInitialValue();
                    }
                },
                deep: true,
            },
            pagination:
            {
                handler: function handler()
                {
                    var me = this;
                    me.$emit('reload', null);
                },
                deep: true,
            },
            checked: function checked()
            {
                var me = this;

                if (!me.multiselect || !me.selectAll)
                {
                    return;
                }

                me.$nextTick(function () {
                    me.fillInitialValue();
                });
            },
        },
    };

    function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier
    /* server only */
    , shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
      if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
      } // Vue.extend constructor export interop.


      var options = typeof script === 'function' ? script.options : script; // render functions

      if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true; // functional template

        if (isFunctionalTemplate) {
          options.functional = true;
        }
      } // scopedId


      if (scopeId) {
        options._scopeId = scopeId;
      }

      var hook;

      if (moduleIdentifier) {
        // server build
        hook = function hook(context) {
          // 2.3 injection
          context = context || // cached call
          this.$vnode && this.$vnode.ssrContext || // stateful
          this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext; // functional
          // 2.2 with runInNewContext: true

          if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
            context = __VUE_SSR_CONTEXT__;
          } // inject component styles


          if (style) {
            style.call(this, createInjectorSSR(context));
          } // register component module identifier for async chunk inference


          if (context && context._registeredComponents) {
            context._registeredComponents.add(moduleIdentifier);
          }
        }; // used by ssr in case component is cached and beforeCreate
        // never gets called


        options._ssrRegister = hook;
      } else if (style) {
        hook = shadowMode ? function () {
          style.call(this, createInjectorShadow(this.$root.$options.shadowRoot));
        } : function (context) {
          style.call(this, createInjector(context));
        };
      }

      if (hook) {
        if (options.functional) {
          // register for functional component in vue file
          var originalRender = options.render;

          options.render = function renderWithStyleInjection(h, context) {
            hook.call(context);
            return originalRender(h, context);
          };
        } else {
          // inject component registration as beforeCreate hook
          var existing = options.beforeCreate;
          options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
      }

      return script;
    }

    var normalizeComponent_1 = normalizeComponent;

    var isOldIE = typeof navigator !== 'undefined' && /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
    function createInjector(context) {
      return function (id, style) {
        return addStyle(id, style);
      };
    }
    var HEAD = document.head || document.getElementsByTagName('head')[0];
    var styles = {};

    function addStyle(id, css) {
      var group = isOldIE ? css.media || 'default' : id;
      var style = styles[group] || (styles[group] = {
        ids: new Set(),
        styles: []
      });

      if (!style.ids.has(id)) {
        style.ids.add(id);
        var code = css.source;

        if (css.map) {
          // https://developer.chrome.com/devtools/docs/javascript-debugging
          // this makes source maps inside style tags work properly in Chrome
          code += '\n/*# sourceURL=' + css.map.sources[0] + ' */'; // http://stackoverflow.com/a/26603875

          code += '\n/*# sourceMappingURL=data:application/json;base64,' + btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) + ' */';
        }

        if (!style.element) {
          style.element = document.createElement('style');
          style.element.type = 'text/css';
          if (css.media) { style.element.setAttribute('media', css.media); }
          HEAD.appendChild(style.element);
        }

        if ('styleSheet' in style.element) {
          style.styles.push(code);
          style.element.styleSheet.cssText = style.styles.filter(Boolean).join('\n');
        } else {
          var index = style.ids.size - 1;
          var textNode = document.createTextNode(code);
          var nodes = style.element.childNodes;
          if (nodes[index]) { style.element.removeChild(nodes[index]); }
          if (nodes.length) { style.element.insertBefore(textNode, nodes[index]); }else { style.element.appendChild(textNode); }
        }
      }
    }

    var browser = createInjector;

    /* script */
    var __vue_script__ = script;

    /* template */
    var __vue_render__ = function() {
      var _vm = this;
      var _h = _vm.$createElement;
      var _c = _vm._self._c || _h;
      return _c(
        "div",
        {
          directives: [
            {
              name: "click-outside",
              rawName: "v-click-outside",
              value: _vm.clickOutsideHandler,
              expression: "clickOutsideHandler"
            }
          ],
          ref: "lb-vue-sel-select",
          staticClass: "lb-select"
        },
        [
          _c(
            "div",
            {
              staticClass: "lb-select-input",
              class: _vm.css,
              attrs: { disabled: _vm.disabled },
              on: {
                click: function($event) {
                  $event.stopPropagation();
                  return _vm.clickSelector.apply(null, arguments)
                }
              }
            },
            [
              _c(
                "div",
                { staticClass: "lb-select-container" },
                [
                  _vm.allSelectedText &&
                  (_vm.list
                    .map(function(item) {
                      return item[_vm.valueField]
                    })
                    .every(function(item) {
                      return _vm.value.split(",").includes(item)
                    }) ||
                    _vm.list
                      .map(function(item) {
                        return item[_vm.valueField].toString()
                      })
                      .every(function(item) {
                        return _vm.value.split(",").includes(item)
                      })) &&
                  _vm.value.split(",").length > 5
                    ? _c("div", { staticClass: "lb-select-item" }, [
                        _vm._v("\n                " + _vm._s(_vm.allSelectedText))
                      ])
                    : _vm._l(_vm.selectedItems, function(item, i) {
                        return _c(
                          "div",
                          { key: i, staticClass: "lb-select-item" },
                          [
                            _c("div", [_vm._v(_vm._s(_vm.getDisplayText(item)))]),
                            _vm._v(" "),
                            _vm.multiselect && _vm.disabled !== true
                              ? _c(
                                  "div",
                                  {
                                    staticClass: "lb_remove",
                                    on: {
                                      click: function($event) {
                                        $event.stopPropagation();
                                        return _vm.selectItem(item)
                                      }
                                    }
                                  },
                                  [
                                    _c(
                                      "svg",
                                      {
                                        attrs: {
                                          version: "1.1",
                                          role: "presentation",
                                          width: "12.571428571428571",
                                          height: "16",
                                          viewBox: "0 0 1408 1792"
                                        }
                                      },
                                      [
                                        _c("path", {
                                          attrs: {
                                            d:
                                              "M1298 1322q0 40-28 68l-136 136q-28 28-68 28t-68-28l-294-294-294 294q-28 28-68 28t-68-28l-136-136q-28-28-28-68t28-68l294-294-294-294q-28-28-28-68t28-68l136-136q28-28 68-28t68 28l294 294 294-294q28-28 68-28t68 28l136 136q28 28 28 68t-28 68l-294 294 294 294q28 28 28 68z"
                                          }
                                        })
                                      ]
                                    )
                                  ]
                                )
                              : _vm._e()
                          ]
                        )
                      })
                ],
                2
              )
            ]
          ),
          _vm._v(" "),
          _vm.showSelector
            ? _c(
                "div",
                { staticClass: "selector" },
                [
                  _vm.multiselect && _vm.selectAll
                    ? [
                        _c("input", {
                          directives: [
                            {
                              name: "model",
                              rawName: "v-model",
                              value: _vm.checked,
                              expression: "checked"
                            }
                          ],
                          attrs: { type: "checkbox" },
                          domProps: {
                            checked: Array.isArray(_vm.checked)
                              ? _vm._i(_vm.checked, null) > -1
                              : _vm.checked
                          },
                          on: {
                            click: _vm.selectAllClick,
                            change: function($event) {
                              var $$a = _vm.checked,
                                $$el = $event.target,
                                $$c = $$el.checked ? true : false;
                              if (Array.isArray($$a)) {
                                var $$v = null,
                                  $$i = _vm._i($$a, $$v);
                                if ($$el.checked) {
                                  $$i < 0 && (_vm.checked = $$a.concat([$$v]));
                                } else {
                                  $$i > -1 &&
                                    (_vm.checked = $$a
                                      .slice(0, $$i)
                                      .concat($$a.slice($$i + 1)));
                                }
                              } else {
                                _vm.checked = $$c;
                              }
                            }
                          }
                        }),
                        _vm._v(_vm._s(_vm.selectAll) + "\n        ")
                      ]
                    : _vm._e(),
                  _vm._v(" "),
                  !_vm.pagination && _vm.searchBox
                    ? [
                        _c("input", {
                          directives: [
                            {
                              name: "model",
                              rawName: "v-model",
                              value: _vm.filterString,
                              expression: "filterString"
                            }
                          ],
                          attrs: { type: "text" },
                          domProps: { value: _vm.filterString },
                          on: {
                            input: function($event) {
                              if ($event.target.composing) {
                                return
                              }
                              _vm.filterString = $event.target.value;
                            }
                          }
                        })
                      ]
                    : _vm._e(),
                  _vm._v(" "),
                  _c("div", { staticClass: "selector-container" }, [
                    _c(
                      "ul",
                      { staticClass: "selector-list" },
                      _vm._l(_vm.filteredList, function(item, i) {
                        return _c(
                          "li",
                          {
                            key: i,
                            class: { selected: item.isSelected },
                            on: {
                              click: function($event) {
                                return _vm.selectItem(item)
                              }
                            }
                          },
                          [_vm._v(_vm._s(_vm.getDisplayText(item)))]
                        )
                      }),
                      0
                    )
                  ]),
                  _vm._v(" "),
                  _vm.pagination
                    ? _c("pagination", {
                        staticClass: "mt-1 p-1",
                        attrs: {
                          totalCount: _vm.totalCount,
                          list: _vm.list,
                          "search-placeholder": _vm.searchPlaceholder,
                          "value-field": "key",
                          "items-placeholder": _vm.itemsPlaceholder
                        },
                        on: { reload: _vm.reload },
                        model: {
                          value: _vm.pagination,
                          callback: function($$v) {
                            _vm.pagination = $$v;
                          },
                          expression: "pagination"
                        }
                      })
                    : _vm._e()
                ],
                2
              )
            : _vm._e()
        ]
      )
    };
    var __vue_staticRenderFns__ = [];
    __vue_render__._withStripped = true;

      /* style */
      var __vue_inject_styles__ = function (inject) {
        if (!inject) { return }
        inject("data-v-3d98ff66_0", { source: "\n.lb-select[data-v-3d98ff66] {\n    position: relative;\n}\n.selected[data-v-3d98ff66] {\n    background-color: lightblue;\n}\n.lb-select .lb-select-input[data-v-3d98ff66] {\n    overflow-x: auto;\n    overflow-y: hidden;\n    position: relative;\n\n    padding: .375rem .75rem;\n    font-size: .875rem;\n    font-weight: 400;\n    line-height: 1.5;\n    color: #3e515b;\n    background-color: #fff;\n    background-clip: padding-box;\n    border: 1px solid #e4e6eb;\n    border-radius: .25rem;\n    -webkit-transition: border-color .15s ease-in-out,-webkit-box-shadow .15s ease-in-out;\n    transition: border-color .15s ease-in-out,-webkit-box-shadow .15s ease-in-out;\n    transition: border-color .15s ease-in-out,box-shadow .15s ease-in-out;\n    transition: border-color .15s ease-in-out,box-shadow .15s ease-in-out,-webkit-box-shadow .15s ease-in-out;\n}\n.lb-select .lb-select-input .lb-select-container[data-v-3d98ff66] {\n    display: flex; /*added*/\n    flex-direction: row; /*added*/\n    white-space: nowrap;\n}\n.lb-select .lb-select-input .lb-select-item[data-v-3d98ff66] {\n    border-radius: 2px;\n    background-color: #004b64;\n    color: #fff;\n    padding: 0 2px;\n    fill: #fff;\n    margin-right: 3px;\n    display: flex;\n    align-items: center;\n    justify-content: center;\n}\n.lb-select-input[disabled][data-v-3d98ff66]{\n    background-color: rgb(214, 214, 214, 0.5);\n}\n.lb-select-input[disabled] .lb-select-item[data-v-3d98ff66]\n{\n    background-color: rgb(0, 75, 100, 0.5);\n}\n.lb-select .lb-select-input .lb-select-item > div[data-v-3d98ff66] {\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    flex-direction: column;\n}\n.lb-select .lb-select-input .lb-select-item .lb_remove[data-v-3d98ff66] {\n    margin: 0 2px;\n}\n.lb-select .selector[data-v-3d98ff66] {\n    position: absolute;\n    top: calc(1.95rem + 2px);\n    left: 0px;\n    border: 1px solid #e4e6eb;\n    background-color: #fff;\n    z-index: 10;\n}\n.lb-select .selector .selector-container[data-v-3d98ff66] {\n    max-height: 300px;\n    overflow: auto;\n}\n.lb-select .selector .selector-list[data-v-3d98ff66] {\n    list-style: none;\n    margin: 0px;\n    padding: 0px;\n    width: 100%;\n}\n.lb-select .selector .selector-list li[data-v-3d98ff66] {\n    list-style: none;\n    margin: 0px;\n    padding: 10px;\n    width: 100%;\n    border-bottom: 1px solid #e4e6eb;\n}\n.lb-select .pagination-container[data-v-3d98ff66] {\n    padding: 5px;\n}\n\n", map: {"version":3,"sources":["/home/dfilkovi/work/env_leapbit/lb-vue-select/src/Select.vue"],"names":[],"mappings":";AAqCA;IACA,kBAAA;AACA;AACA;IACA,2BAAA;AACA;AACA;IACA,gBAAA;IACA,kBAAA;IACA,kBAAA;;IAEA,uBAAA;IACA,kBAAA;IACA,gBAAA;IACA,gBAAA;IACA,cAAA;IACA,sBAAA;IACA,4BAAA;IACA,yBAAA;IACA,qBAAA;IACA,qFAAA;IACA,6EAAA;IACA,qEAAA;IACA,yGAAA;AACA;AAEA;IACA,aAAA,EAAA,QAAA;IACA,mBAAA,EAAA,QAAA;IACA,mBAAA;AACA;AAEA;IACA,kBAAA;IACA,yBAAA;IACA,WAAA;IACA,cAAA;IACA,UAAA;IACA,iBAAA;IACA,aAAA;IACA,mBAAA;IACA,uBAAA;AACA;AACA;IACA,yCAAA;AACA;AACA;;IAEA,sCAAA;AACA;AAEA;IACA,aAAA;IACA,mBAAA;IACA,uBAAA;IACA,sBAAA;AACA;AAEA;IACA,aAAA;AACA;AAEA;IACA,kBAAA;IACA,wBAAA;IACA,SAAA;IACA,yBAAA;IACA,sBAAA;IACA,WAAA;AACA;AAEA;IACA,iBAAA;IACA,cAAA;AACA;AAEA;IACA,gBAAA;IACA,WAAA;IACA,YAAA;IACA,WAAA;AACA;AAEA;IACA,gBAAA;IACA,WAAA;IACA,aAAA;IACA,WAAA;IACA,gCAAA;AACA;AAEA;IACA,YAAA;AACA","file":"Select.vue","sourcesContent":["<template>\n    <div class=\"lb-select\" v-click-outside=\"clickOutsideHandler\" ref=\"lb-vue-sel-select\">\n        <div class=\"lb-select-input\" :disabled=\"disabled\" :class=\"css\" v-on:click.stop=\"clickSelector\">\n            <div class=\"lb-select-container\">\n                <div class=\"lb-select-item\" v-if=\"allSelectedText && (list.map((item) => item[valueField]).every((item) => value.split(',').includes(item)) || list.map((item) => item[valueField].toString()).every((item) => value.split(',').includes(item))) && value.split(',').length > 5\">\n                    {{allSelectedText}}</div>\n                <template v-else>\n                <div v-for=\"(item, i) in selectedItems\" :key=\"i\" class=\"lb-select-item\">\n                    <div>{{getDisplayText(item)}}</div>\n                    <div v-if=\"multiselect && disabled !== true\" class=\"lb_remove\" v-on:click.stop=\"selectItem(item)\"><svg version=\"1.1\" role=\"presentation\" width=\"12.571428571428571\" height=\"16\" viewBox=\"0 0 1408 1792\"><path d=\"M1298 1322q0 40-28 68l-136 136q-28 28-68 28t-68-28l-294-294-294 294q-28 28-68 28t-68-28l-136-136q-28-28-28-68t28-68l294-294-294-294q-28-28-28-68t28-68l136-136q28-28 68-28t68 28l294 294 294-294q28-28 68-28t68 28l136 136q28 28 28 68t-28 68l-294 294 294 294q28 28 28 68z\"></path></svg>\n                    </div>\n                </div>\n                </template>\n            </div>\n        </div>\n        <div class=\"selector\" v-if=\"showSelector\">\n            <template v-if=\"multiselect && selectAll\">\n                <input type=\"checkbox\" v-model=\"checked\" v-on:click=\"selectAllClick\">{{selectAll}}\n            </template>\n            <template v-if=\"!pagination && searchBox\">\n                <input type=\"text\" v-model=\"filterString\">\n            </template>\n            <div class=\"selector-container\">\n                <ul class=\"selector-list\">\n                    <li :class=\"{selected :item.isSelected}\"\n                    v-for=\"(item, i) in filteredList\"\n                    :key=\"i\"\n                    v-on:click=\"selectItem(item);\">{{getDisplayText(item)}}</li>\n                </ul>\n            </div>\n            <pagination class=\"mt-1 p-1\" v-if=\"pagination\" v-bind:totalCount=\"totalCount\" v-model=\"pagination\" :list=\"list\" v-on:reload=\"reload\" :search-placeholder=\"searchPlaceholder\" value-field=\"key\" :items-placeholder=\"itemsPlaceholder\"></pagination>\n        </div>\n    </div>\n</template>\n\n<style scoped=\"\">\n\n    .lb-select {\n        position: relative;\n    }\n    .selected {\n        background-color: lightblue;\n    }\n    .lb-select .lb-select-input {\n        overflow-x: auto;\n        overflow-y: hidden;\n        position: relative;\n\n        padding: .375rem .75rem;\n        font-size: .875rem;\n        font-weight: 400;\n        line-height: 1.5;\n        color: #3e515b;\n        background-color: #fff;\n        background-clip: padding-box;\n        border: 1px solid #e4e6eb;\n        border-radius: .25rem;\n        -webkit-transition: border-color .15s ease-in-out,-webkit-box-shadow .15s ease-in-out;\n        transition: border-color .15s ease-in-out,-webkit-box-shadow .15s ease-in-out;\n        transition: border-color .15s ease-in-out,box-shadow .15s ease-in-out;\n        transition: border-color .15s ease-in-out,box-shadow .15s ease-in-out,-webkit-box-shadow .15s ease-in-out;\n    }\n\n    .lb-select .lb-select-input .lb-select-container {\n        display: flex; /*added*/\n        flex-direction: row; /*added*/\n        white-space: nowrap;\n    }\n\n    .lb-select .lb-select-input .lb-select-item {\n        border-radius: 2px;\n        background-color: #004b64;\n        color: #fff;\n        padding: 0 2px;\n        fill: #fff;\n        margin-right: 3px;\n        display: flex;\n        align-items: center;\n        justify-content: center;\n    }\n    .lb-select-input[disabled]{\n        background-color: rgb(214, 214, 214, 0.5);\n    }\n    .lb-select-input[disabled] .lb-select-item\n    {\n        background-color: rgb(0, 75, 100, 0.5);\n    }\n\n    .lb-select .lb-select-input .lb-select-item > div {\n        display: flex;\n        align-items: center;\n        justify-content: center;\n        flex-direction: column;\n    }\n\n    .lb-select .lb-select-input .lb-select-item .lb_remove {\n        margin: 0 2px;\n    }\n\n    .lb-select .selector {\n        position: absolute;\n        top: calc(1.95rem + 2px);\n        left: 0px;\n        border: 1px solid #e4e6eb;\n        background-color: #fff;\n        z-index: 10;\n    }\n\n    .lb-select .selector .selector-container {\n        max-height: 300px;\n        overflow: auto;\n    }\n\n    .lb-select .selector .selector-list {\n        list-style: none;\n        margin: 0px;\n        padding: 0px;\n        width: 100%;\n    }\n\n    .lb-select .selector .selector-list li {\n        list-style: none;\n        margin: 0px;\n        padding: 10px;\n        width: 100%;\n        border-bottom: 1px solid #e4e6eb;\n    }\n\n    .lb-select .pagination-container {\n        padding: 5px;\n    }\n\n</style>\n\n<script>\n\nimport ClickOutside from 'vue-click-outside';\nimport Pagination from 'lb-vue-pagination';\n\nexport default\n{\n    name: 'LbSelect',\n    props: {\n        value: {\n            type: [String, Number],\n        },\n        list: {\n            type: Array,\n        },\n        pagination: {\n            type: Object,\n        },\n        displayField: {\n            type: String,\n            default: 'key',\n        },\n        displayFunc: {\n            type: Function,\n        },\n        valueField: {\n            type: String,\n            default: 'value',\n        },\n        multiselect: {\n            type: Boolean,\n            default: false,\n        },\n        searchBox: {\n            type: Boolean,\n            default: false,\n        },\n        empty: {\n            type: Boolean,\n            default: false,\n        },\n        searchPlaceholder: {\n            type: String,\n            default: undefined,\n        },\n        itemsPlaceholder: {\n            type: String,\n            default: undefined,\n        },\n        totalCount: {\n            type: Number,\n            default: undefined,\n        },\n        css: {\n            type: String,\n            default: 'form-control',\n        },\n        selectAll: {\n            type: String,\n            default: undefined,\n        },\n        allSelectedText: {\n            type: String,\n            default: undefined,\n        },\n        disabled: {\n            type: Boolean,\n            default: false,\n        },\n    },\n    data()\n    {\n        return {\n            showSelector: false,\n            selectedItems: [],\n            checked: false,\n            filterString: '',\n        };\n    },\n    directives: {\n        'click-outside': ClickOutside,\n    },\n    components:\n    {\n        pagination: Pagination,\n    },\n    created()\n    {\n        const me = this;\n\n        me.fillInitialValue();\n    },\n    methods:\n    {\n        selectAllClick()\n        {\n            const me = this;\n\n            if (me.checked === true)\n            {\n                me.checked = false;\n                me.$emit('change', '');\n                me.$emit('input', '');\n\n                for (const item of me.list)\n                {\n                    item.isSelected = false;\n                }\n            }\n        },\n        clickSelector()\n        {\n            const me = this;\n\n            me.$emit('click');\n\n            if (me.disabled !== true)\n            {\n                me.showSelector = !me.showSelector;\n            }\n            else\n            {\n                me.showSelector = false;\n            }\n        },\n        recursChildNodes(childNodes, target)\n        {\n            for (const node of childNodes)\n            {\n                if (node === target)\n                {\n                    return true;\n                }\n\n                if (this.recursChildNodes(node.childNodes, target))\n                {\n                    return true;\n                }\n            }\n            return false;\n        },\n        clickOutsideHandler(evt)\n        {\n            if (this.showSelector)\n            {\n                const [clickedElement] = evt.composedPath();\n\n                if (clickedElement\n                && this.recursChildNodes(this.$refs['lb-vue-sel-select'].childNodes, clickedElement))\n                {\n                    return;\n                }\n\n                this.close();\n            }\n        },\n        close()\n        {\n            const me = this;\n            me.showSelector = false;\n        },\n        reload()\n        {\n            const me = this;\n\n            me.$emit('reload');\n        },\n        getDisplayText(item)\n        {\n            const me = this;\n\n            if (me.displayFunc !== undefined)\n            {\n                return me.displayFunc(item);\n            }\n\n            return item[me.displayField];\n        },\n        selectItem(item)\n        {\n            const me = this;\n\n            const index = me.selectedItems.indexOf(item);\n            if (me.multiselect)\n            {\n                if (index === -1)\n                {\n                    item.isSelected = true;\n                    me.selectedItems.push(item);\n                }\n                else\n                {\n                    item.isSelected = false;\n                    me.selectedItems.splice(index, 1);\n\n                    if (me.selectAll)\n                    {\n                        me.checked = false;\n                    }\n                }\n            }\n            else if (me.empty)\n            {\n                if (index !== -1)\n                {\n                    me.selectedItems.splice(0);\n                }\n                else\n                {\n                    me.list.forEach((element) =>\n                    {\n                        element.isSelected = false;\n                    });\n                    me.selectedItems.splice(0);\n                    me.selectedItems.push(item);\n                }\n            }\n            else\n            {\n                me.list.forEach((element) =>\n                {\n                    element.isSelected = false;\n                });\n                me.selectedItems.splice(0);\n                me.selectedItems.push(item);\n            }\n\n            const valueArr = [];\n\n            for (const val of me.selectedItems)\n            {\n                valueArr.push(val[me.valueField]);\n            }\n\n            me.$emit('change', valueArr.join(','));\n\n            me.$emit('input', valueArr.join(','));\n\n            if (!me.multiselect)\n            {\n                me.close();\n            }\n        },\n        fillInitialValue()\n        {\n            const me = this;\n\n            me.selectedItems = [];\n\n            if (!me.list)\n            {\n                return;\n            }\n\n            if (me.list.length === undefined)\n            {\n                console.error('lb-vue-select: List is not an array');\n            }\n\n            if (me.value === undefined || me.value == null)\n            {\n                return;\n            }\n\n            let isNumber = false;\n            let tempValue = me.value;\n\n            if (typeof tempValue === 'number')\n            {\n                tempValue = tempValue.toString();\n                isNumber = true;\n            }\n\n            const valueArr = tempValue.split(',');\n\n            const valuesFromList = me.list.map((item) =>\n            {\n                if (item[me.valueField] == null)\n                {\n                    return null;\n                }\n                return item[me.valueField].toString();\n            });\n            if (me.multiselect && me.selectAll && valuesFromList.every((item) => valueArr.includes(item)))\n            {\n                me.checked = true;\n            }\n\n            if (me.multiselect && me.selectAll && me.checked)\n            {\n                for (const item of me.list)\n                {\n                    me.selectItem(item);\n                }\n            }\n\n            for (let val of valueArr)\n            {\n                if (val === '')\n                {\n                    continue;\n                }\n                if (isNumber)\n                {\n                    val = parseInt(val, 10);\n                }\n                let foundInList = false;\n                for (const item of me.list)\n                {\n                    if (!me.multiselect)\n                    {\n                        item.isSelected = false;\n                    }\n\n                    if (String(item[me.valueField]) === String(val))\n                    {\n                        foundInList = true;\n                        let found = false;\n                        for (const sel of me.selectedItems)\n                        {\n                            if (String(sel[me.valueField]) === String(val))\n                            {\n                                found = true;\n                            }\n                        }\n                        if (!found)\n                        {\n                            item.isSelected = true;\n                            me.selectedItems.push(item);\n                        }\n                    }\n                }\n\n                if (!foundInList && me.pagination !== undefined)\n                {\n                    if (me.multiselect)\n                    {\n                        if (!me.pagination.initialId.includes(val))\n                        {\n                            me.pagination.initialId.push(val);\n                        }\n                    }\n                    else\n                    {\n                        me.pagination.initialId.splice(0);\n                        me.pagination.initialId.push(val);\n                    }\n                }\n            }\n        },\n    },\n    computed:\n    {\n        displayValue()\n        {\n            const me = this;\n\n            me.setInitialId();\n\n            return me.value;\n        },\n        filteredList()\n        {\n            const me = this;\n\n            const items = [];\n\n            if (me.filterString === '')\n            {\n                return me.list;\n            }\n\n            for (const item of me.list)\n            {\n                if (me.getDisplayText(item).toLowerCase().includes(me.filterString))\n                {\n                    items.push(item);\n                }\n            }\n\n            return items;\n        },\n    },\n    watch:\n    {\n        value()\n        {\n            const me = this;\n\n            me.fillInitialValue();\n        },\n        list:\n        {\n            handler(oldVal, val)\n            {\n                const me = this;\n                if (JSON.stringify(oldVal) !== JSON.stringify(val))\n                {\n                    me.fillInitialValue();\n                }\n            },\n            deep: true,\n        },\n        pagination:\n        {\n            handler()\n            {\n                const me = this;\n                me.$emit('reload', null);\n            },\n            deep: true,\n        },\n        checked()\n        {\n            const me = this;\n\n            if (!me.multiselect || !me.selectAll)\n            {\n                return;\n            }\n\n            me.$nextTick(() =>\n            {\n                me.fillInitialValue();\n            });\n        },\n    },\n};\n</script>\n"]}, media: undefined });

      };
      /* scoped */
      var __vue_scope_id__ = "data-v-3d98ff66";
      /* module identifier */
      var __vue_module_identifier__ = undefined;
      /* functional template */
      var __vue_is_functional_template__ = false;
      /* style inject SSR */
      

      
      var component = normalizeComponent_1(
        { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
        __vue_inject_styles__,
        __vue_script__,
        __vue_scope_id__,
        __vue_is_functional_template__,
        __vue_module_identifier__,
        browser,
        undefined
      );

    // Import vue component

    exports.default = component;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
